@@ -1,26 +1,29 @@
-#
-# This file is part of Games::Risk.
-# Copyright (c) 2008 Jerome Quelin, all rights reserved.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU GPLv3+.
-#
-#
-
-package Games::Risk;
-
+# 
+# This file is part of Games-Risk
+# 
+# This software is Copyright (c) 2008 by Jerome Quelin.
+# 
+# This is free software, licensed under:
+# 
+#   The GNU General Public License, Version 3, June 2007
+# 
 use 5.010;
 use strict;
 use warnings;
 
+package Games::Risk;
+BEGIN {
+  $Games::Risk::VERSION = '3.101110';
+}
+# ABSTRACT: classical 'risk' board game
+
+
 use Games::Risk::Controller;
 use Games::Risk::GUI;
 use List::Util qw{ shuffle };
-use POE;
+use POE        qw{ Loop::Tk };
 use constant K => $poe_kernel;
 
-# Public variables of the module.
-our $VERSION = '2.1.2';
 
 use base qw{ Class::Accessor::Fast };
 __PACKAGE__->mk_accessors( qw{
@@ -42,7 +45,7 @@ sub new {
     # only one game at a time
     return $singleton if defined $singleton;
 
-    my ($pkg, $args) = @_;
+    my $pkg = shift;
 
     # create object
     $singleton = {};
@@ -233,15 +236,17 @@ sub send_to_one {
 
 1;
 
-__END__
 
 
+=pod
 
 =head1 NAME
 
 Games::Risk - classical 'risk' board game
 
+=head1 VERSION
 
+version 3.101110
 
 =head1 SYNOPSIS
 
@@ -250,8 +255,6 @@ Games::Risk - classical 'risk' board game
     POE::Kernel->run;
     exit;
 
-
-
 =head1 DESCRIPTION
 
 Risk is a strategic turn-based board game. Players control armies, with
@@ -266,13 +269,10 @@ This distribution implements a graphical interface for this game.
 C<Games::Risk> itself tracks everything needed for a risk game. It is
 also used as a heap for C<Games::Risk::Controller> POE session.
 
-
-
 =head1 METHODS
 
 =head2 Constructor
 
-
 =over 4
 
 =item * my $game = Games::Risk->new
@@ -280,31 +280,25 @@ also used as a heap for C<Games::Risk::Controller> POE session.
 Create a new risk game. No params needed. Note: this class implements a
 singleton scheme.
 
-
 =back
 
-
 =head2 Accessors
 
 The following accessors (acting as mutators, ie getters and setters) are
 available for C<Games::Risk> objects:
 
-
 =over 4
 
 =item * armies()
 
 armies left to be placed.
 
-
 =item * map()
 
 the current C<Games::Risk::Map> object of the game.
 
-
 =back
 
-
 =head2 Public methods
 
 =over 4
@@ -313,62 +307,49 @@ the current C<Games::Risk::Map> object of the game.
 
 Put back all cards given to players to the deck.
 
-
 =item * $game->destroy;
 
 Break all circular references in C<$game>, to reclaim all objects
 referenced.
 
-
 =item * $game->player_lost( $player )
 
 Remove $player from the list of active players.
 
-
 =item * my $player = $game->player_next()
 
 Return the next player to play, or undef if the turn is over. Of course,
 players that have lost will never be returned.
 
-
 =item * my @players = $game->players()
 
 Return the C<Games::Risk::Player> objects of the current game. Note that
 some of those players may have already lost.
 
-
 =item * my @players = $game->players_active;
 
 Return the list of active players (Games::Risk::Player objects).
 
-
 =item * $game->players_reset( @players )
 
 Remove all players, and replace them by C<@players>.
 
-
 =item * $game->players_reset_turn()
 
 Mark all players to be in "turn to do", effectively marking them as
 still in play. Typically called during initial army placing, or real
 game start.
 
-
 =item * $game->send_to_all($event, @params)
 
 Send C<$event> (with C<@params>) to all players.
 
-
 =item * $game->send_to_one($player, $event, @params)
 
 Send C<$event> (with C<@params>) to one C<$player>.
 
-
 =back
 
-
-
-
 =head1 TODO
 
 This is a work in progress. While there are steady improvements, here's
@@ -413,14 +394,11 @@ in the future for C<Games::Risk>:
 
 =back
 
-
 However, the game is already totally playable by now: reinforcements,
 continent bonus, country cards, different artificial intelligences...
 Therefore, version 1.0.0 has been released with those basic
 requirements. Except new features soon!
 
-
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-games-risk at
@@ -429,8 +407,6 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Games-Risk>.  I will be
 notified, and then you'll automatically be notified of progress on your
 bug as I make changes.
 
-
-
 =head1 SEE ALSO
 
 You can find more information on the classical C<risk> game on wikipedia
@@ -439,7 +415,6 @@ at L<http://en.wikipedia.org/wiki/Risk_game>.
 You might also want to check jRisk, a java-based implementation of Risk,
 which inspired me quite a lot.
 
-
 You can also look for information on this module at:
 
 =over 4
@@ -448,21 +423,16 @@ You can also look for information on this module at:
 
 L<http://annocpan.org/dist/Games-Risk>
 
-
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/Games-Risk>
 
-
 =item * Open bugs
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Risk>
 
-
 =back
 
-
-
 =head1 ACKNOWLEDGEMENTS
 
 I definitely recommend you to buy a C<risk> board game and play with
@@ -473,14 +443,10 @@ Some ideas  & artwork taken from project C<jrisk>, available at
 L<http://risk.sourceforge.net/>. Others (ideas & artwork once again)
 taken from teg, available at L<http://teg.sourceforge.net/>
 
-
-
 =head1 AUTHOR
 
 Jerome Quelin, C<< <jquelin@cpan.org> >>
 
-
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright (c) 2008 Jerome Quelin, all rights reserved.
@@ -488,6 +454,22 @@ Copyright (c) 2008 Jerome Quelin, all rights reserved.
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU GPLv3+.
 
+=head1 AUTHOR
+
+  Jerome Quelin
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2008 by Jerome Quelin.
+
+This is free software, licensed under:
+
+  The GNU General Public License, Version 3, June 2007
 
 =cut
 
+
+__END__
+
+
+
