@@ -1,18 +1,22 @@
-#
-# This file is part of Games::Risk.
-# Copyright (c) 2008 Jerome Quelin, all rights reserved.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU GPLv3+.
-#
-#
-
-package Games::Risk::AI::Blitzkrieg;
-
+# 
+# This file is part of Games-Risk
+# 
+# This software is Copyright (c) 2008 by Jerome Quelin.
+# 
+# This is free software, licensed under:
+# 
+#   The GNU General Public License, Version 3, June 2007
+# 
 use 5.010;
 use strict;
 use warnings;
 
+package Games::Risk::AI::Blitzkrieg;
+BEGIN {
+  $Games::Risk::AI::Blitzkrieg::VERSION = '3.101110';
+}
+# ABSTRACT: easy ai that does blitzkrieg attacks
+
 use List::Util qw{ shuffle };
 
 use base qw{ Games::Risk::AI };
@@ -36,7 +40,7 @@ sub attack {
     my $player = $self->player;
 
     # find first possible attack
-    my ($src, $dst);
+    #my ($src, $dst);
     COUNTRY:
     foreach my $country ( shuffle $player->countries )  {
         # don't attack unless there's somehow a chance to win
@@ -64,7 +68,7 @@ sub attack {
 # $dst.
 #
 sub attack_move {
-    my ($self, $src, $dst, $min) = @_;
+    my ($self, $src) = @_;
     return $src->armies - 1;
 }
 
@@ -96,7 +100,7 @@ sub difficulty { return 'easy' }
 # which will be its attack base during attack phase.
 #
 sub place_armies {
-    my ($self, $nb, $continent) = @_;
+    my ($self, $nb) = @_;
     my $player = $self->player;
 
     # FIXME: restrict to continent if strict placing
@@ -147,36 +151,33 @@ sub _description {
 
 1;
 
-__END__
 
 
+=pod
 
 =head1 NAME
 
 Games::Risk::AI::Blitzkrieg - easy ai that does blitzkrieg attacks
 
+=head1 VERSION
 
+version 3.101110
 
 =head1 SYNOPSIS
 
     my $ai = Games::Risk::AI::Blitzkrieg->new(\%params);
 
-
-
 =head1 DESCRIPTION
 
 This module implements a quite easy ai for risk, that plays according to
 a blitzkrieg strategy. It will piles up new armies in one country, and
 then follow a random path from this attack base.
 
-
-
 =head1 METHODS
 
 This class implements (or inherits) all of those methods (further described in
 C<Games::Risk::AI>):
 
-
 =over 4
 
 =item * attack()
@@ -193,20 +194,14 @@ C<Games::Risk::AI>):
 
 =back
 
-
-
 =head1 SEE ALSO
 
 L<Games::Risk::AI>, L<Games::Risk>.
 
-
-
 =head1 AUTHOR
 
 Jerome Quelin, C<< <jquelin at cpan.org> >>
 
-
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright (c) 2008 Jerome Quelin, all rights reserved.
@@ -214,5 +209,24 @@ Copyright (c) 2008 Jerome Quelin, all rights reserved.
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU GPLv3+.
 
+=head1 AUTHOR
+
+  Jerome Quelin
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2008 by Jerome Quelin.
+
+This is free software, licensed under:
+
+  The GNU General Public License, Version 3, June 2007
+
 =cut
 
+
+__END__
+
+
+
+
+
