@@ -1,20 +1,24 @@
-#
-# This file is part of Games::Risk.
-# Copyright (c) 2008 Jerome Quelin, all rights reserved.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU GPLv3+.
-#
-#
-
-package Games::Risk::GUI::GameOver;
-
+# 
+# This file is part of Games-Risk
+# 
+# This software is Copyright (c) 2008 by Jerome Quelin.
+# 
+# This is free software, licensed under:
+# 
+#   The GNU General Public License, Version 3, June 2007
+# 
 use 5.010;
 use strict;
 use warnings;
 
+package Games::Risk::GUI::GameOver;
+BEGIN {
+  $Games::Risk::GUI::GameOver::VERSION = '3.101110';
+}
+# ABSTRACT: window used when game is over
+
 use Games::Risk::GUI::Constants;
-use POE;
+use POE qw{ Loop::Tk };
 use Tk;
 use Tk::Font;
 
@@ -31,7 +35,7 @@ use constant K => $poe_kernel;
 # embedded pod for an explanation of the supported options.
 #
 sub spawn {
-    my ($class, $args) = @_;
+    my (undef, $args) = @_;
 
     my $session = POE::Session->create(
         args          => [ $args ],
@@ -124,20 +128,17 @@ sub _onpriv_but_close {
 
 1;
 
-__END__
 
 
+=pod
+
 =head1 NAME
 
 Games::Risk::GUI::GameOver - window used when game is over
 
+=head1 VERSION
 
-
-=head1 SYNOPSYS
-
-    my $id = Games::Risk::GUI::GameOver->spawn(%opts);
-
-
+version 3.101110
 
 =head1 DESCRIPTION
 
@@ -145,11 +146,12 @@ C<GR::GUI::GameOver> implements a POE session, creating a Tk window to
 announce the winner of the game. The window and asession are only used
 once, then discarded.
 
+=head1 SYNOPSYS
 
+    my $id = Games::Risk::GUI::GameOver->spawn(%opts);
 
 =head1 CLASS METHODS
 
-
 =head2 my $id = Games::Risk::GUI::GameOver->spawn( %opts );
 
 Create a window, and return the associated POE session ID. One can pass
@@ -162,35 +164,24 @@ the following options:
 A Tk window that will be the parent of the toplevel window created. This
 parameter is mandatory.
 
-
 =item winner => $player
 
 The player that won the game. This parameter is mandatory.
 
-
 =back
 
-
-
-
 =head1 PUBLIC EVENTS
 
 The newly created POE session does not accept nor fires any events.
 
-
-
 =head1 SEE ALSO
 
 L<Games::Risk>.
 
-
-
 =head1 AUTHOR
 
 Jerome Quelin, C<< <jquelin at cpan.org> >>
 
-
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright (c) 2008 Jerome Quelin, all rights reserved.
@@ -198,5 +189,22 @@ Copyright (c) 2008 Jerome Quelin, all rights reserved.
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU GPLv3+.
 
+=head1 AUTHOR
+
+  Jerome Quelin
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2008 by Jerome Quelin.
+
+This is free software, licensed under:
+
+  The GNU General Public License, Version 3, June 2007
+
 =cut
 
+
+__END__
+
+
+
