@@ -1,18 +1,22 @@
-#
-# This file is part of Games::Risk.
-# Copyright (c) 2008 Jerome Quelin, all rights reserved.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU GPLv3+.
-#
-#
-
-package Games::Risk::Map;
-
+# 
+# This file is part of Games-Risk
+# 
+# This software is Copyright (c) 2008 by Jerome Quelin.
+# 
+# This is free software, licensed under:
+# 
+#   The GNU General Public License, Version 3, June 2007
+# 
 use 5.010;
 use strict;
 use warnings;
 
+package Games::Risk::Map;
+BEGIN {
+  $Games::Risk::Map::VERSION = '3.101110';
+}
+# ABSTRACT: map being played
+
 use File::Basename qw{ fileparse };
 use List::Util      qw{ shuffle };
 use List::MoreUtils qw{ uniq };
@@ -189,7 +193,7 @@ sub load_file {
 # FIXME: the following are UGLY, UGLY, UGLY!
 
 sub _parse_file_section_ {
-    my ($self, $line) = @_;
+    my ($self) = @_;
     return 'wtf?';
 }
 
@@ -298,29 +302,27 @@ sub _parse_file_section_files {
 
 1;
 
-__END__
 
 
+=pod
 
 =head1 NAME
 
 Games::Risk::Map - map being played
 
+=head1 VERSION
 
+version 3.101110
 
 =head1 SYNOPSIS
 
     my $id = Games::Risk::Map->new(\%params);
 
-
-
 =head1 DESCRIPTION
 
 This module implements a map, pointing to the continents, the
 countries, etc. of the game currently in play.
 
-
-
 =head1 METHODS
 
 =head2 Constructor
@@ -329,32 +331,25 @@ countries, etc. of the game currently in play.
 
 =item * my $player = Games::Risk::Map->new( \%params )
 
-
 =back
 
-
 =head2 Accessors
 
-
 The following accessors (acting as mutators, ie getters and setters) are
 available for C<Games::Risk::Map> objects:
 
-
 =over 4
 
 =item * background()
 
 the path to the background image for the board.
 
-
 =item * greyscale()
 
 the path to the greyscale bitmap for the board.
 
-
 =back
 
-
 =head2 Object methods
 
 =over 4
@@ -363,43 +358,34 @@ the path to the greyscale bitmap for the board.
 
 Break all circular references in C<$map>, to prevent memory leaks.
 
-
 =item * my $card = $map->card_get()
 
 Return the next card from the cards stack.
 
-
 =item * $map->card_return( $card )
 
 Push back a $card in the card stack.
 
-
 =item * my @continents = $map->continents()
 
 Return the list of all continents in the C<$map>.
 
-
 =item * my @owned = $map->continents_owned;
 
 Return a list with all continents that are owned by a single player.
 
-
 =item * my @countries = $map->countries()
 
 Return the list of all countries in the C<$map>.
 
-
 =item * my $country = $map->country_get($id)
 
 Return the country which id matches C<$id>.
 
-
 =item * $map->load_file( \%params )
 
 =back
 
-
-
 =begin quiet_pod_coverage
 
 =item Card (inserted by aliased)
@@ -410,20 +396,14 @@ Return the country which id matches C<$id>.
 
 =end quiet_pod_coverage
 
-
-
 =head1 SEE ALSO
 
 L<Games::Risk>.
 
-
-
 =head1 AUTHOR
 
 Jerome Quelin, C<< <jquelin at cpan.org> >>
 
-
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright (c) 2008 Jerome Quelin, all rights reserved.
@@ -431,5 +411,23 @@ Copyright (c) 2008 Jerome Quelin, all rights reserved.
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU GPLv3+.
 
+=head1 AUTHOR
+
+  Jerome Quelin
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2008 by Jerome Quelin.
+
+This is free software, licensed under:
+
+  The GNU General Public License, Version 3, June 2007
+
 =cut
 
+
+__END__
+
+
+
+
