@@ -1,22 +1,26 @@
-#
-# This file is part of Games::Risk.
-# Copyright (c) 2008 Jerome Quelin, all rights reserved.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU GPLv3+.
-#
-#
-
-package Games::Risk::Player;
-
+# 
+# This file is part of Games-Risk
+# 
+# This software is Copyright (c) 2008 by Jerome Quelin.
+# 
+# This is free software, licensed under:
+# 
+#   The GNU General Public License, Version 3, June 2007
+# 
 use 5.010;
 use strict;
 use warnings;
 
+package Games::Risk::Player;
+BEGIN {
+  $Games::Risk::Player::VERSION = '3.101110';
+}
+# ABSTRACT: risk player
+
 use Carp;
 use Games::Risk::AI;
 use List::Util qw{ sum };
-use POE;
+use POE qw{ Loop::Tk };
 use Readonly;
 use UNIVERSAL::require;
 use constant K => $poe_kernel;
@@ -173,80 +177,65 @@ sub greatness {
 
 1;
 
-__END__
 
 
+=pod
 
 =head1 NAME
 
 Games::Risk::Player - risk player
 
+=head1 VERSION
 
+version 3.101110
 
 =head1 SYNOPSIS
 
     my $id = Games::Risk::Player->new(\%params);
 
-
-
 =head1 DESCRIPTION
 
 This module implements a risk player, with all its characteristics.
 
-
-
 =head1 METHODS
 
 =head2 Constructor
 
-
 =over 4
 
 =item * my $player = Games::Risk::Player->new( \%params )
 
-
 =back
 
-
-
 =head2 Accessors
 
-
 The following accessors (acting as mutators, ie getters and setters) are
 available for C<Games::Risk::Player> objects:
 
-
 =over 4
 
 =item * ai_class
 
 the class of the artificial intelligence, if player is an ai.
 
-
 =item * color
 
 player color to be used in the gui.
 
-
 =item * name
 
 player name.
 
-
 =item * type
 
 player type (human, ai, etc.)
 
-
 =back
 
-
-
 =head2 Object methods
 
 The following methods are available for C<Games::Risk::Player> objects:
 
-
 =over 4
 
 =item my @cards = $player->cards()
@@ -254,60 +243,46 @@ The following methods are available for C<Games::Risk::Player> objects:
 Return the list of cards (C<Games::Risk::Card> objects) currently
 owned by C<$player>.
 
-
 =item * $player->card_add( $card )
 
 Add C<$card> to the set of cards owned by C<$player>.
 
-
 =item * $player->card_del( $card )
 
 Remove C<$card> from the set of cards owned by C<player>.
 
-
 =item * my @countries = $player->countries()
 
 Return the list of countries (C<Games::Risk::Country> objects)
 currently owned by C<$player>.
 
-
 =item * $player->country_add( $country )
 
 Add C<$country> to the set of countries owned by C<$player>.
 
-
 =item * $player->country_del( $country )
 
 Delete C<$country> from the set of countries owned by C<$player>.
 
-
 =item * $player->destroy()
 
 Break all circular references in C<$player>, to prevent memory leaks.
 
-
 =item * my $greatness = $player->greatness()
 
 Return an integer reflecting the greatness of C<$player>. It will raise
 with the number of owned territories, as well as the number of armies.
 
-
 =back
 
-
-
 =head1 SEE ALSO
 
 L<Games::Risk>.
 
-
-
 =head1 AUTHOR
 
 Jerome Quelin, C<< <jquelin at cpan.org> >>
 
-
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright (c) 2008 Jerome Quelin, all rights reserved.
@@ -315,5 +290,24 @@ Copyright (c) 2008 Jerome Quelin, all rights reserved.
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU GPLv3+.
 
+=head1 AUTHOR
+
+  Jerome Quelin
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2008 by Jerome Quelin.
+
+This is free software, licensed under:
+
+  The GNU General Public License, Version 3, June 2007
+
 =cut
 
+
+__END__
+
+
+
+
+
